==> tomee-project-8.0.13-source-release.zip: tomee-project-8.0.13/arquillian/arquillian-tomee-embedded/src/test/java/org/apache/openejb/arquillian/embedded/AnEJB.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.openejb.arquillian.embedded;

import javax.ejb.Singleton;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.naming.OperationNotSupportedException;

@Singleton
public class AnEJB {
    public String test() {
        return "ok";
    }
    
    public String createSubContext() {
    	try {
			Context context = new InitialContext();
			try {
				Context subContext = context.createSubcontext("sub");
				if(subContext == null) {
					return null;
				} else {
					return "created";
				}
			} catch (OperationNotSupportedException e) {
				return OperationNotSupportedException.class.getName();
			}
		} catch (NamingException e) {
			return "failure " + e;
		}
    }
}

==> tomee-project-10.1.4-source-release.zip: tomee-project-10.1.4/arquillian/arquillian-tomee-embedded/src/test/java/org/apache/openejb/arquillian/embedded/AnEJB.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.openejb.arquillian.embedded;

import jakarta.ejb.Singleton;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.naming.OperationNotSupportedException;

@Singleton
public class AnEJB {
    public String test() {
        return "ok";
    }
    
    public String createSubContext() {
    	try {
			Context context = new InitialContext();
			try {
				Context subContext = context.createSubcontext("sub");
				if(subContext == null) {
					return null;
				} else {
					return "created";
				}
			} catch (OperationNotSupportedException e) {
				return OperationNotSupportedException.class.getName();
			}
		} catch (NamingException e) {
			return "failure " + e;
		}
    }
}
